@@ -291,8 +291,8 @@ class PysonConnect:
                     "status":status,
                     "status_reason":status_reason,
                     "start_date":start_date,
-                    "job_name":jobName,
-                    "ttl_pages":ttlPages,
+                    "job_name":job_name,
+                    "ttl_pages":ttl_pages,
                     "update_date":update_date
                     }
             return return_data
@@ -325,7 +325,7 @@ class PysonConnect:
             return_data = {
                     "printer_name":printer_name,
                     "serial_no":serial_no,
-                    "ec_connected":ecConnected
+                    "ec_connected":ec_connected
                     }
             return return_data
 
